@@ -10,21 +10,23 @@ use Pinto::Types qw(AuthorID);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_002'; # VERSION
+our $VERSION = '0.036'; # VERSION
 
 #------------------------------------------------------------------------------
 
 with qw( Pinto::Role::Attribute::pausecfg
-         Pinto::Role::Attribute::username );
+         Pinto::Role::Attribute::username
+         Pinto::Meta::Attribute::Trait::Postable );
 
 #------------------------------------------------------------------------------
 
 has author => (
     is         => 'ro',
     isa        => AuthorID,
-    builder    => '_build_author',
     coerce     => 1,
     lazy       => 1,
+    builder    => '_build_author',
+    traits     => [ qw(Postable) ],
 );
 
 #------------------------------------------------------------------------------
@@ -55,7 +57,7 @@ Pinto::Role::Attribute::author - Something that has an author id attribute
 
 =head1 VERSION
 
-version 0.040_002
+version 0.036
 
 =head1 AUTHOR
 
