@@ -10,7 +10,11 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_002'; # VERSION
+our $VERSION = '0.036'; # VERSION
+
+#------------------------------------------------------------------------------
+
+with qw( Pinto::Meta::Attribute::Trait::Postable );
 
 #------------------------------------------------------------------------------
 
@@ -18,6 +22,7 @@ has norecurse => (
     is        => 'ro',
     isa       => Bool,
     default   => 0,
+    traits    => [ qw(Postable) ],
 );
 
 #------------------------------------------------------------------------------
@@ -36,7 +41,7 @@ Pinto::Role::Attribute::norecurse - Something that has a norecurse attribute
 
 =head1 VERSION
 
-version 0.040_002
+version 0.036
 
 =head1 AUTHOR
 
