@@ -10,7 +10,11 @@ use Carp;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_002'; # VERSION
+our $VERSION = '0.036'; # VERSION
+
+#------------------------------------------------------------------------------
+
+with qw( Pinto::Meta::Attribute::Trait::Postable );
 
 #------------------------------------------------------------------------------
 
@@ -19,6 +23,7 @@ has username => (
     isa        => Str,
     lazy       => 1,
     builder    => '_build_username',
+    traits     => [ qw(Postable) ],
 );
 
 #------------------------------------------------------------------------------
@@ -56,7 +61,7 @@ Pinto::Role::Attribute::username - Something that has a username attribute
 
 =head1 VERSION
 
-version 0.040_002
+version 0.036
 
 =head1 AUTHOR
 
