@@ -8,17 +8,14 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_002'; # VERSION
+our $VERSION = '0.036'; # VERSION
 
 #------------------------------------------------------------------------------
 
 with qw( Pinto::Role::Interface::Action
          Pinto::Role::Attribute::author
-         Pinto::Role::Attribute::archives
-         Pinto::Role::Attribute::stack
-         Pinto::Role::Attribute::pin
-         Pinto::Role::Attribute::norecurse
-         Pinto::Role::Attribute::dryrun );
+         Pinto::Role::Attribute::archive
+         Pinto::Role::Attribute::norecurse );
 
 #------------------------------------------------------------------------------
 
@@ -36,7 +33,7 @@ Pinto::Role::Interface::Action::Add - Interface for Action::Add
 
 =head1 VERSION
 
-version 0.040_002
+version 0.036
 
 =head1 AUTHOR
 
