@@ -3,46 +3,63 @@
 package Pinto::Role::Interface::Action::List;
 
 use Moose::Role;
-use MooseX::Types::Moose qw(Str Bool);
+
+use MooseX::Types::Moose qw(Maybe Str Bool HashRef);
 
 use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_002'; # VERSION
+our $VERSION = '0.036'; # VERSION
 
 #------------------------------------------------------------------------------
 
 with qw( Pinto::Role::Interface::Action
          Pinto::Role::Attribute::out
-         Pinto::Role::Attribute::stack );
+         Pinto::Meta::Attribute::Trait::Postable );
 
 #------------------------------------------------------------------------------
 
 has format => (
-    is        => 'ro',
-    isa       => Str,
-    default   => "%m%s%y %-40n %12v  %p\n",
-    predicate => 'has_format',
-    lazy      => 1,
+    is      => 'ro',
+    isa     => Str,
+    traits  => [ qw(Postable) ],
 );
 
 
 has pinned => (
     is     => 'ro',
     isa    => Bool,
+    traits => [ qw(Postable) ],
+);
+
+
+has index => (
+    is     => 'ro',
+    isa    => Str,
+    traits => [ qw(Postable) ],
 );
 
 
 has packages => (
     is     => 'ro',
     isa    => Str,
+    traits => [ qw(Postable) ],
 );
 
 
 has distributions => (
     is     => 'ro',
     isa    => Str,
+    traits => [ qw(Postable) ],
+);
+
+
+has where => (
+    is      => 'ro',
+    isa     => HashRef,
+    builder => '_build_where',
+    lazy    => 1,
 );
 
 #------------------------------------------------------------------------------
@@ -61,7 +78,7 @@ Pinto::Role::Interface::Action::List - Interface for Action::List
 
 =head1 VERSION
 
-version 0.040_002
+version 0.036
 
 =head1 AUTHOR
 
