@@ -10,11 +10,12 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_002'; # VERSION
+our $VERSION = '0.036'; # VERSION
 
 #------------------------------------------------------------------------------
 
-with qw(Pinto::Role::Interface::Action);
+with qw( Pinto::Role::Interface::Action
+         Pinto::Meta::Attribute::Trait::Postable );
 
 #------------------------------------------------------------------------------
 
@@ -22,6 +23,7 @@ has sleep => (
     is      => 'ro',
     isa     => Int,
     default => 0,
+    traits  => [ qw(Postable) ],
 );
 
 #------------------------------------------------------------------------------
@@ -40,7 +42,7 @@ Pinto::Role::Interface::Action::Nop - Interface for Action::Nop;
 
 =head1 VERSION
 
-version 0.040_002
+version 0.036
 
 =head1 AUTHOR
 
