@@ -8,13 +8,12 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_002'; # VERSION
+our $VERSION = '0.036'; # VERSION
 
 #------------------------------------------------------------------------------
 
 with qw( Pinto::Role::Interface::Action
-         Pinto::Role::Attribute::targets
-         Pinto::Role::Attribute::stack );
+         Pinto::Role::Attribute::package );
 
 #------------------------------------------------------------------------------
 
@@ -32,7 +31,7 @@ Pinto::Role::Interface::Action::Unpin - Interface for Action::Unpin
 
 =head1 VERSION
 
-version 0.040_002
+version 0.036
 
 =head1 AUTHOR
 
